# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import roles_pb2 as roles__pb2


class RolesStub(object):
  """Roles are tools for controlling user access to resources. Each Role holds a
  list of resources which they grant access to. Composite roles are a special
  type of Role which have no resource associations of their own, but instead
  grant access to the combined resources associated with a set of child roles.
  Each user can be a member of one Role or composite role.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/v1.Roles/Create',
        request_serializer=roles__pb2.RoleCreateRequest.SerializeToString,
        response_deserializer=roles__pb2.RoleCreateResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/v1.Roles/Get',
        request_serializer=roles__pb2.RoleGetRequest.SerializeToString,
        response_deserializer=roles__pb2.RoleGetResponse.FromString,
        )
    self.Update = channel.unary_unary(
        '/v1.Roles/Update',
        request_serializer=roles__pb2.RoleUpdateRequest.SerializeToString,
        response_deserializer=roles__pb2.RoleUpdateResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/v1.Roles/Delete',
        request_serializer=roles__pb2.RoleDeleteRequest.SerializeToString,
        response_deserializer=roles__pb2.RoleDeleteResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/v1.Roles/List',
        request_serializer=roles__pb2.RoleListRequest.SerializeToString,
        response_deserializer=roles__pb2.RoleListResponse.FromString,
        )


class RolesServicer(object):
  """Roles are tools for controlling user access to resources. Each Role holds a
  list of resources which they grant access to. Composite roles are a special
  type of Role which have no resource associations of their own, but instead
  grant access to the combined resources associated with a set of child roles.
  Each user can be a member of one Role or composite role.
  """

  def Create(self, request, context):
    """Create registers a new Role.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Get reads one Role by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Update patches a Role by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Delete removes a Role by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """List gets a list of Roles matching a given set of criteria.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RolesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=roles__pb2.RoleCreateRequest.FromString,
          response_serializer=roles__pb2.RoleCreateResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=roles__pb2.RoleGetRequest.FromString,
          response_serializer=roles__pb2.RoleGetResponse.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=roles__pb2.RoleUpdateRequest.FromString,
          response_serializer=roles__pb2.RoleUpdateResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=roles__pb2.RoleDeleteRequest.FromString,
          response_serializer=roles__pb2.RoleDeleteResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=roles__pb2.RoleListRequest.FromString,
          response_serializer=roles__pb2.RoleListResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'v1.Roles', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 

# This file was generated by protogen. DO NOT EDIT.

import grpc
from . import plumbing
from . import models
from .options_pb2 import *
from .options_pb2_grpc import *
from .spec_pb2 import *
from .spec_pb2_grpc import *
from .account_attachments_pb2 import *
from .account_attachments_pb2_grpc import *
from .account_grants_pb2 import *
from .account_grants_pb2_grpc import *
from .accounts_pb2 import *
from .accounts_pb2_grpc import *
from .drivers_pb2 import *
from .drivers_pb2_grpc import *
from .nodes_pb2 import *
from .nodes_pb2_grpc import *
from .resources_pb2 import *
from .resources_pb2_grpc import *
from .role_attachments_pb2 import *
from .role_attachments_pb2_grpc import *
from .role_grants_pb2 import *
from .role_grants_pb2_grpc import *
from .roles_pb2 import *
from .roles_pb2_grpc import *
class AccountAttachments:
    """AccountAttachments assign an account to a role."""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = AccountAttachmentsStub(channel)
    def create(self,
        account_attachment,
        options=None,
        timeout=None):
        """Create registers a new AccountAttachment."""
        req = AccountAttachmentCreateRequest()
			
        if account_attachment is not None:
            req.account_attachment.CopyFrom(plumbing.account_attachment_to_plumbing(account_attachment))
        if options is not None:
            req.options.CopyFrom(plumbing.account_attachment_create_options_to_plumbing(options))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('AccountAttachments.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountAttachmentCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account_attachment = plumbing.account_attachment_to_porcelain(plumbing_response.account_attachment)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one AccountAttachment by ID."""
        req = AccountAttachmentGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('AccountAttachments.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountAttachmentGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account_attachment = plumbing.account_attachment_to_porcelain(plumbing_response.account_attachment)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a AccountAttachment by ID."""
        req = AccountAttachmentDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('AccountAttachments.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountAttachmentDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of AccountAttachments matching a given set of criteria."""
        req = AccountAttachmentListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('AccountAttachments.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.account_attachments:
                    yield plumbing.account_attachment_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class AccountGrants:
    """AccountGrants connect a resource directly to an account, giving the account the permission to connect to that resource."""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = AccountGrantsStub(channel)
    def create(self,
        account_grant,
        timeout=None):
        """Create registers a new AccountGrant."""
        req = AccountGrantCreateRequest()
			
        if account_grant is not None:
            req.account_grant.CopyFrom(plumbing.account_grant_to_plumbing(account_grant))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('AccountGrants.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountGrantCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account_grant = plumbing.account_grant_to_porcelain(plumbing_response.account_grant)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one AccountGrant by ID."""
        req = AccountGrantGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('AccountGrants.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountGrantGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account_grant = plumbing.account_grant_to_porcelain(plumbing_response.account_grant)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a AccountGrant by ID."""
        req = AccountGrantDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('AccountGrants.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountGrantDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of AccountGrants matching a given set of criteria."""
        req = AccountGrantListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('AccountGrants.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.account_grants:
                    yield plumbing.account_grant_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class Accounts:
    """Accounts are users that have access to strongDM.
 There are two types of accounts:
 1. **Regular users:** humans who are authenticated through username and password or SSO
 2. **Service users:** machines that are authneticated using a service token"""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = AccountsStub(channel)
    def create(self,
        account,
        timeout=None):
        """Create registers a new Account."""
        req = AccountCreateRequest()
			
        if account is not None:
            req.account.CopyFrom(plumbing.account_to_plumbing(account))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('Accounts.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account = plumbing.account_to_porcelain(plumbing_response.account)
        resp.token = plumbing_response.token
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one Account by ID."""
        req = AccountGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('Accounts.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account = plumbing.account_to_porcelain(plumbing_response.account)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def update(self,
        account,
        timeout=None):
        """Update patches a Account by ID."""
        req = AccountUpdateRequest()
			
        if account is not None:
            req.account.CopyFrom(plumbing.account_to_plumbing(account))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Update(req, metadata=self.parent.get_metadata('Accounts.Update', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountUpdateResponse()
        resp.meta = plumbing.update_response_metadata_to_porcelain(plumbing_response.meta)
        resp.account = plumbing.account_to_porcelain(plumbing_response.account)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a Account by ID."""
        req = AccountDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('Accounts.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.AccountDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of Accounts matching a given set of criteria."""
        req = AccountListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('Accounts.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.accounts:
                    yield plumbing.account_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class Nodes:
    """Nodes make up the strongDM network, and allow your users to connect securely to your resources.
 There are two types of nodes:
 1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
 1. **Gateways:** a relay that also listens for connections from strongDM clients"""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = NodesStub(channel)
    def create(self,
        node,
        timeout=None):
        """Create registers a new Node."""
        req = NodeCreateRequest()
			
        if node is not None:
            req.node.CopyFrom(plumbing.node_to_plumbing(node))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('Nodes.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.NodeCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.node = plumbing.node_to_porcelain(plumbing_response.node)
        resp.token = plumbing_response.token
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one Node by ID."""
        req = NodeGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('Nodes.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.NodeGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.node = plumbing.node_to_porcelain(plumbing_response.node)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def update(self,
        node,
        timeout=None):
        """Update patches a Node by ID."""
        req = NodeUpdateRequest()
			
        if node is not None:
            req.node.CopyFrom(plumbing.node_to_plumbing(node))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Update(req, metadata=self.parent.get_metadata('Nodes.Update', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.NodeUpdateResponse()
        resp.meta = plumbing.update_response_metadata_to_porcelain(plumbing_response.meta)
        resp.node = plumbing.node_to_porcelain(plumbing_response.node)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a Node by ID."""
        req = NodeDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('Nodes.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.NodeDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of Nodes matching a given set of criteria."""
        req = NodeListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('Nodes.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.nodes:
                    yield plumbing.node_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class Resources:
    """"""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = ResourcesStub(channel)
    def create(self,
        resource,
        timeout=None):
        """Create registers a new Resource."""
        req = ResourceCreateRequest()
			
        if resource is not None:
            req.resource.CopyFrom(plumbing.resource_to_plumbing(resource))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('Resources.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.ResourceCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.resource = plumbing.resource_to_porcelain(plumbing_response.resource)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one Resource by ID."""
        req = ResourceGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('Resources.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.ResourceGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.resource = plumbing.resource_to_porcelain(plumbing_response.resource)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def update(self,
        resource,
        timeout=None):
        """Update patches a Resource by ID."""
        req = ResourceUpdateRequest()
			
        if resource is not None:
            req.resource.CopyFrom(plumbing.resource_to_plumbing(resource))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Update(req, metadata=self.parent.get_metadata('Resources.Update', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.ResourceUpdateResponse()
        resp.meta = plumbing.update_response_metadata_to_porcelain(plumbing_response.meta)
        resp.resource = plumbing.resource_to_porcelain(plumbing_response.resource)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a Resource by ID."""
        req = ResourceDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('Resources.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.ResourceDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of Resources matching a given set of criteria."""
        req = ResourceListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('Resources.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.resources:
                    yield plumbing.resource_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class RoleAttachments:
    """RoleAttachments represent relationships between composite roles and the roles
 that make up those composite roles. When a composite role is attached to another
 role, the permissions granted to members of the composite role are augmented to
 include the permissions granted to members of the attached role."""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = RoleAttachmentsStub(channel)
    def create(self,
        role_attachment,
        timeout=None):
        """Create registers a new RoleAttachment."""
        req = RoleAttachmentCreateRequest()
			
        if role_attachment is not None:
            req.role_attachment.CopyFrom(plumbing.role_attachment_to_plumbing(role_attachment))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('RoleAttachments.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleAttachmentCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role_attachment = plumbing.role_attachment_to_porcelain(plumbing_response.role_attachment)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one RoleAttachment by ID."""
        req = RoleAttachmentGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('RoleAttachments.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleAttachmentGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role_attachment = plumbing.role_attachment_to_porcelain(plumbing_response.role_attachment)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a RoleAttachment by ID."""
        req = RoleAttachmentDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('RoleAttachments.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleAttachmentDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of RoleAttachments matching a given set of criteria."""
        req = RoleAttachmentListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('RoleAttachments.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.role_attachments:
                    yield plumbing.role_attachment_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class RoleGrants:
    """RoleGrants represent relationships between composite roles and the roles
 that make up those composite roles. When a composite role is attached to another
 role, the permissions granted to members of the composite role are augmented to
 include the permissions granted to members of the attached role."""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = RoleGrantsStub(channel)
    def create(self,
        role_grant,
        timeout=None):
        """Create registers a new RoleGrant."""
        req = RoleGrantCreateRequest()
			
        if role_grant is not None:
            req.role_grant.CopyFrom(plumbing.role_grant_to_plumbing(role_grant))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('RoleGrants.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleGrantCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role_grant = plumbing.role_grant_to_porcelain(plumbing_response.role_grant)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one RoleGrant by ID."""
        req = RoleGrantGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('RoleGrants.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleGrantGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role_grant = plumbing.role_grant_to_porcelain(plumbing_response.role_grant)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a RoleGrant by ID."""
        req = RoleGrantDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('RoleGrants.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleGrantDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of RoleGrants matching a given set of criteria."""
        req = RoleGrantListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('RoleGrants.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.role_grants:
                    yield plumbing.role_grant_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)
class Roles:
    """Roles are tools for controlling user access to resources. Each Role holds a
 list of resources which they grant access to. Composite roles are a special
 type of Role which have no resource associations of their own, but instead
 grant access to the combined resources associated with a set of child roles.
 Each user can be a member of one Role or composite role."""
    def __init__(self, channel, client):
        self.parent = client
        self.stub = RolesStub(channel)
    def create(self,
        role,
        timeout=None):
        """Create registers a new Role."""
        req = RoleCreateRequest()
			
        if role is not None:
            req.role.CopyFrom(plumbing.role_to_plumbing(role))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Create(req, metadata=self.parent.get_metadata('Roles.Create', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleCreateResponse()
        resp.meta = plumbing.create_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role = plumbing.role_to_porcelain(plumbing_response.role)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def get(self,
        id,
        timeout=None):
        """Get reads one Role by ID."""
        req = RoleGetRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Get(req, metadata=self.parent.get_metadata('Roles.Get', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleGetResponse()
        resp.meta = plumbing.get_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role = plumbing.role_to_porcelain(plumbing_response.role)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def update(self,
        role,
        timeout=None):
        """Update patches a Role by ID."""
        req = RoleUpdateRequest()
			
        if role is not None:
            req.role.CopyFrom(plumbing.role_to_plumbing(role))
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Update(req, metadata=self.parent.get_metadata('Roles.Update', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleUpdateResponse()
        resp.meta = plumbing.update_response_metadata_to_porcelain(plumbing_response.meta)
        resp.role = plumbing.role_to_porcelain(plumbing_response.role)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def delete(self,
        id,
        timeout=None):
        """Delete removes a Role by ID."""
        req = RoleDeleteRequest()
			
        req.id = id
        tries = 0
        plumbing_response = None
        while True:
            try:
                plumbing_response = self.stub.Delete(req, metadata=self.parent.get_metadata('Roles.Delete', req), timeout=timeout)
            except Exception as e:
                if self.parent.shouldRetry(tries, e):
                    tries += 1
                    self.parent.jitterSleep(tries)
                    continue
                raise plumbing.error_to_porcelain(e) from e
            break

			
        resp = models.RoleDeleteResponse()
        resp.meta = plumbing.delete_response_metadata_to_porcelain(plumbing_response.meta)
        resp.rate_limit = plumbing.rate_limit_metadata_to_porcelain(plumbing_response.rate_limit)
        return resp
    def list(self,
        filter,
        *args,
        timeout=None):
        """List gets a list of Roles matching a given set of criteria."""
        req = RoleListRequest()
        req.meta.CopyFrom(ListRequestMetadata())
        page_size_option = self.parent._test_options.get('PageSize')
        if isinstance(page_size_option, int):
            req.meta.limit = page_size_option
			
        req.filter = plumbing.quote_filter_args(filter, *args)
        def generator(svc, req):
            tries = 0
            while True:
                try:
                    plumbing_response = svc.stub.List(req, metadata= svc.parent.get_metadata('Roles.List',req), timeout=timeout)
                except Exception as e:
                    if self.parent.shouldRetry(tries, e):
                        tries += 1
                        self.parent.jitterSleep(tries)
                        continue
                    raise plumbing.error_to_porcelain(e) from e
                tries = 0
                for plumbing_item in plumbing_response.roles:
                    yield plumbing.role_to_porcelain(plumbing_item)
                if plumbing_response.meta.next_cursor == '':
                    break
                req.meta.cursor = plumbing_response.meta.next_cursor
        return generator(self, req)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import nodes_pb2 as nodes__pb2


class NodesStub(object):
  """Nodes make up the strongDM network, and allow your users to connect securely to your resources.
  There are two types of nodes:
  1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
  1. **Gateways:** a relay that also listens for connections from strongDM clients
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/v1.Nodes/Create',
        request_serializer=nodes__pb2.NodeCreateRequest.SerializeToString,
        response_deserializer=nodes__pb2.NodeCreateResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/v1.Nodes/Get',
        request_serializer=nodes__pb2.NodeGetRequest.SerializeToString,
        response_deserializer=nodes__pb2.NodeGetResponse.FromString,
        )
    self.Update = channel.unary_unary(
        '/v1.Nodes/Update',
        request_serializer=nodes__pb2.NodeUpdateRequest.SerializeToString,
        response_deserializer=nodes__pb2.NodeUpdateResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/v1.Nodes/Delete',
        request_serializer=nodes__pb2.NodeDeleteRequest.SerializeToString,
        response_deserializer=nodes__pb2.NodeDeleteResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/v1.Nodes/List',
        request_serializer=nodes__pb2.NodeListRequest.SerializeToString,
        response_deserializer=nodes__pb2.NodeListResponse.FromString,
        )


class NodesServicer(object):
  """Nodes make up the strongDM network, and allow your users to connect securely to your resources.
  There are two types of nodes:
  1. **Relay:** creates connectivity to your datasources, while maintaining the egress-only nature of your firewall
  1. **Gateways:** a relay that also listens for connections from strongDM clients
  """

  def Create(self, request, context):
    """Create registers a new Node.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Get reads one Node by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Update(self, request, context):
    """Update patches a Node by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Delete removes a Node by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """List gets a list of Nodes matching a given set of criteria.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=nodes__pb2.NodeCreateRequest.FromString,
          response_serializer=nodes__pb2.NodeCreateResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=nodes__pb2.NodeGetRequest.FromString,
          response_serializer=nodes__pb2.NodeGetResponse.SerializeToString,
      ),
      'Update': grpc.unary_unary_rpc_method_handler(
          servicer.Update,
          request_deserializer=nodes__pb2.NodeUpdateRequest.FromString,
          response_serializer=nodes__pb2.NodeUpdateResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=nodes__pb2.NodeDeleteRequest.FromString,
          response_serializer=nodes__pb2.NodeDeleteResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=nodes__pb2.NodeListRequest.FromString,
          response_serializer=nodes__pb2.NodeListResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'v1.Nodes', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# This file was generated by protogen. DO NOT EDIT.

class RPCError(Exception):
    """A generic RPC error"""
    def __init__(self, msg, code):
        self.msg = msg
        self.code = code

class AlreadyExistsError(RPCError):
    """Used when an entity already exists in the system"""
    def __init__(self, msg):
        super().__init__(msg, 6)

class NotFoundError(RPCError):
    """Used when an entity does not exist in the system"""
    def __init__(self, msg):
        super().__init__(msg, 5)

class BadRequestError(RPCError):
    """Identifies a bad request sent by the client"""
    def __init__(self, msg):
        super().__init__(msg, 3)

class AuthenticationError(RPCError):
    """Used to specify an authentication failure condition"""
    def __init__(self, msg):
        super().__init__(msg, 16)

class PermissionError(RPCError):
    """Used to specify a permissions violation"""
    def __init__(self, msg):
        super().__init__(msg, 7)

class InternalError(RPCError):
    """Used to specify an internal system error"""
    def __init__(self, msg):
        super().__init__(msg, 13)

class RateLimitError(RPCError):
    """Used when rate limit is exceeded"""
    def __init__(self, msg, rate_limit):
        super().__init__(msg, 8)
        self.rate_limit = rate_limit

class TimeoutError(RPCError):
    """Used when a request takes too long"""
    def __init__(self):
        super().__init__('deadline exceeded', 4)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='accounts.proto',
  package='v1',
  syntax='proto3',
  serialized_options=_b('\n\034com.strongdm.api.v1.plumbingB\020AccountsPlumbing'),
  serialized_pb=_b('\n\x0e\x61\x63\x63ounts.proto\x12\x02v1\x1a\x1cgoogle/api/annotations.proto\x1a,protoc-gen-swagger/options/annotations.proto\x1a\roptions.proto\x1a\nspec.proto\"i\n\x14\x41\x63\x63ountCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd5\x01\n\x15\x41\x63\x63ountCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05token\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"Q\n\x11\x41\x63\x63ountGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb4\x01\n\x12\x41\x63\x63ountGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"u\n\x14\x41\x63\x63ountUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xba\x01\n\x15\x41\x63\x63ountUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"W\n\x14\x41\x63\x63ountDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x90\x01\n\x15\x41\x63\x63ountDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"W\n\x12\x41\x63\x63ountListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x9f\x01\n\x13\x41\x63\x63ountListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12)\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32\x0b.v1.AccountB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd4\x01\n\x07\x41\x63\x63ount\x12\x18\n\x04user\x18\x01 \x01(\x0b\x32\x08.v1.UserH\x00\x12\x1e\n\x07service\x18\x02 \x01(\x0b\x32\x0b.v1.ServiceH\x00:a\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07R\xc2\xf3\xb3\x07M\xa2\xf3\xb3\x07 tf_examples/account_resource.txt\xaa\xf3\xb3\x07#tf_examples/account_data_source.txtB,\n\x07\x61\x63\x63ount\x12!\xaa\xf8\xb3\x07\t\xa2\xf8\xb3\x07\x04User\xaa\xf8\xb3\x07\x0e\xaa\xf8\xb3\x07\tsuspended\"\xf5\x01\n\x04User\x12&\n\x02id\x18\x01 \x01(\tB\x1a\xf2\xf8\xb3\x07\x15\xa2\xf3\xb3\x07\x02ID\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x04User\x12(\n\x05\x65mail\x18\x02 \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xa2\xf3\xb3\x07\x05\x45mail\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x31\n\nfirst_name\x18\x03 \x01(\tB\x1d\xf2\xf8\xb3\x07\x18\xa2\xf3\xb3\x07\tFirstName\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\tlast_name\x18\x04 \x01(\tB\x1c\xf2\xf8\xb3\x07\x17\xa2\xf3\xb3\x07\x08LastName\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\tsuspended\x18\x05 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf3\xb3\x07\x01:\x13\xfa\xf8\xb3\x07\x0e\xa2\xf3\xb3\x07\x04User\xa8\xf3\xb3\x07\x01\"\x96\x01\n\x07Service\x12&\n\x02id\x18\x01 \x01(\tB\x1a\xf2\xf8\xb3\x07\x15\xa2\xf3\xb3\x07\x02ID\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x04User\x12*\n\x04name\x18\x02 \x01(\tB\x1c\xf2\xf8\xb3\x07\x17\xa2\xf3\xb3\x07\x08LastName\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\tsuspended\x18\x03 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf3\xb3\x07\x01:\x13\xfa\xf8\xb3\x07\x0e\xa2\xf3\xb3\x07\x04User\xa8\xf3\xb3\x07\x01\x32\xab\x04\n\x08\x41\x63\x63ounts\x12\xb4\x01\n\x06\x43reate\x12\x18.v1.AccountCreateRequest\x1a\x19.v1.AccountCreateResponse\"u\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/accounts:\x01*\x92\x41[\"Y\n\x1bLearn how to make a Account\x12:https://www.strongdm.com/docs/api/services/Accounts#Create\x12O\n\x03Get\x12\x15.v1.AccountGetRequest\x1a\x16.v1.AccountGetResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/accounts/{id}\x12[\n\x06Update\x12\x18.v1.AccountUpdateRequest\x1a\x19.v1.AccountUpdateResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x1a\x11/v1/accounts/{id}:\x01*\x12X\n\x06\x44\x65lete\x12\x18.v1.AccountDeleteRequest\x1a\x19.v1.AccountDeleteResponse\"\x19\x82\xd3\xe4\x93\x02\x13*\x11/v1/accounts/{id}\x12M\n\x04List\x12\x16.v1.AccountListRequest\x1a\x17.v1.AccountListResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/accounts\x1a\x11\xca\xf9\xb3\x07\x0c\xc2\xf9\xb3\x07\x07\x41\x63\x63ountB0\n\x1c\x63om.strongdm.api.v1.plumbingB\x10\x41\x63\x63ountsPlumbingb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,options__pb2.DESCRIPTOR,spec__pb2.DESCRIPTOR,])




_ACCOUNTCREATEREQUEST = _descriptor.Descriptor(
  name='AccountCreateRequest',
  full_name='v1.AccountCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountCreateRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='v1.AccountCreateRequest.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=230,
)


_ACCOUNTCREATERESPONSE = _descriptor.Descriptor(
  name='AccountCreateResponse',
  full_name='v1.AccountCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountCreateResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='v1.AccountCreateResponse.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='v1.AccountCreateResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountCreateResponse.rate_limit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=446,
)


_ACCOUNTGETREQUEST = _descriptor.Descriptor(
  name='AccountGetRequest',
  full_name='v1.AccountGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGetRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountGetRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=529,
)


_ACCOUNTGETRESPONSE = _descriptor.Descriptor(
  name='AccountGetResponse',
  full_name='v1.AccountGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGetResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='v1.AccountGetResponse.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountGetResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=712,
)


_ACCOUNTUPDATEREQUEST = _descriptor.Descriptor(
  name='AccountUpdateRequest',
  full_name='v1.AccountUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountUpdateRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountUpdateRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='v1.AccountUpdateRequest.account', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=831,
)


_ACCOUNTUPDATERESPONSE = _descriptor.Descriptor(
  name='AccountUpdateResponse',
  full_name='v1.AccountUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountUpdateResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='v1.AccountUpdateResponse.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountUpdateResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=1020,
)


_ACCOUNTDELETEREQUEST = _descriptor.Descriptor(
  name='AccountDeleteRequest',
  full_name='v1.AccountDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountDeleteRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountDeleteRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1109,
)


_ACCOUNTDELETERESPONSE = _descriptor.Descriptor(
  name='AccountDeleteResponse',
  full_name='v1.AccountDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountDeleteResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountDeleteResponse.rate_limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1256,
)


_ACCOUNTLISTREQUEST = _descriptor.Descriptor(
  name='AccountListRequest',
  full_name='v1.AccountListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountListRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='v1.AccountListRequest.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1258,
  serialized_end=1345,
)


_ACCOUNTLISTRESPONSE = _descriptor.Descriptor(
  name='AccountListResponse',
  full_name='v1.AccountListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountListResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='v1.AccountListResponse.accounts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\270\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountListResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1507,
)


_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='v1.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='v1.Account.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='v1.Account.service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001\372\370\263\007R\302\363\263\007M\242\363\263\007 tf_examples/account_resource.txt\252\363\263\007#tf_examples/account_data_source.txt'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='account', full_name='v1.Account.account',
      index=0, containing_type=None, fields=[], serialized_options=_b('\252\370\263\007\t\242\370\263\007\004User\252\370\263\007\016\252\370\263\007\tsuspended')),
  ],
  serialized_start=1510,
  serialized_end=1722,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='v1.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.User.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\025\242\363\263\007\002ID\260\363\263\007\001\312\363\263\007\004User'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='v1.User.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\024\242\363\263\007\005Email\260\363\263\007\001\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='v1.User.first_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\030\242\363\263\007\tFirstName\260\363\263\007\001\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='v1.User.last_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\027\242\363\263\007\010LastName\260\363\263\007\001\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspended', full_name='v1.User.suspended', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\n\260\363\263\007\001\320\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\016\242\363\263\007\004User\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1970,
)


_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='v1.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.Service.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\025\242\363\263\007\002ID\260\363\263\007\001\312\363\263\007\004User'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.Service.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\027\242\363\263\007\010LastName\260\363\263\007\001\300\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspended', full_name='v1.Service.suspended', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\n\260\363\263\007\001\320\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\016\242\363\263\007\004User\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2123,
)

_ACCOUNTCREATEREQUEST.fields_by_name['meta'].message_type = spec__pb2._CREATEREQUESTMETADATA
_ACCOUNTCREATEREQUEST.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTCREATERESPONSE.fields_by_name['meta'].message_type = spec__pb2._CREATERESPONSEMETADATA
_ACCOUNTCREATERESPONSE.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTCREATERESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTGETREQUEST.fields_by_name['meta'].message_type = spec__pb2._GETREQUESTMETADATA
_ACCOUNTGETRESPONSE.fields_by_name['meta'].message_type = spec__pb2._GETRESPONSEMETADATA
_ACCOUNTGETRESPONSE.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTGETRESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTUPDATEREQUEST.fields_by_name['meta'].message_type = spec__pb2._UPDATEREQUESTMETADATA
_ACCOUNTUPDATEREQUEST.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTUPDATERESPONSE.fields_by_name['meta'].message_type = spec__pb2._UPDATERESPONSEMETADATA
_ACCOUNTUPDATERESPONSE.fields_by_name['account'].message_type = _ACCOUNT
_ACCOUNTUPDATERESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTDELETEREQUEST.fields_by_name['meta'].message_type = spec__pb2._DELETEREQUESTMETADATA
_ACCOUNTDELETERESPONSE.fields_by_name['meta'].message_type = spec__pb2._DELETERESPONSEMETADATA
_ACCOUNTDELETERESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTLISTREQUEST.fields_by_name['meta'].message_type = spec__pb2._LISTREQUESTMETADATA
_ACCOUNTLISTRESPONSE.fields_by_name['meta'].message_type = spec__pb2._LISTRESPONSEMETADATA
_ACCOUNTLISTRESPONSE.fields_by_name['accounts'].message_type = _ACCOUNT
_ACCOUNTLISTRESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNT.fields_by_name['user'].message_type = _USER
_ACCOUNT.fields_by_name['service'].message_type = _SERVICE
_ACCOUNT.oneofs_by_name['account'].fields.append(
  _ACCOUNT.fields_by_name['user'])
_ACCOUNT.fields_by_name['user'].containing_oneof = _ACCOUNT.oneofs_by_name['account']
_ACCOUNT.oneofs_by_name['account'].fields.append(
  _ACCOUNT.fields_by_name['service'])
_ACCOUNT.fields_by_name['service'].containing_oneof = _ACCOUNT.oneofs_by_name['account']
DESCRIPTOR.message_types_by_name['AccountCreateRequest'] = _ACCOUNTCREATEREQUEST
DESCRIPTOR.message_types_by_name['AccountCreateResponse'] = _ACCOUNTCREATERESPONSE
DESCRIPTOR.message_types_by_name['AccountGetRequest'] = _ACCOUNTGETREQUEST
DESCRIPTOR.message_types_by_name['AccountGetResponse'] = _ACCOUNTGETRESPONSE
DESCRIPTOR.message_types_by_name['AccountUpdateRequest'] = _ACCOUNTUPDATEREQUEST
DESCRIPTOR.message_types_by_name['AccountUpdateResponse'] = _ACCOUNTUPDATERESPONSE
DESCRIPTOR.message_types_by_name['AccountDeleteRequest'] = _ACCOUNTDELETEREQUEST
DESCRIPTOR.message_types_by_name['AccountDeleteResponse'] = _ACCOUNTDELETERESPONSE
DESCRIPTOR.message_types_by_name['AccountListRequest'] = _ACCOUNTLISTREQUEST
DESCRIPTOR.message_types_by_name['AccountListResponse'] = _ACCOUNTLISTRESPONSE
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['User'] = _USER
DESCRIPTOR.message_types_by_name['Service'] = _SERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountCreateRequest = _reflection.GeneratedProtocolMessageType('AccountCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATEREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountCreateRequest)
  })
_sym_db.RegisterMessage(AccountCreateRequest)

AccountCreateResponse = _reflection.GeneratedProtocolMessageType('AccountCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATERESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountCreateResponse)
  })
_sym_db.RegisterMessage(AccountCreateResponse)

AccountGetRequest = _reflection.GeneratedProtocolMessageType('AccountGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGETREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGetRequest)
  })
_sym_db.RegisterMessage(AccountGetRequest)

AccountGetResponse = _reflection.GeneratedProtocolMessageType('AccountGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGETRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGetResponse)
  })
_sym_db.RegisterMessage(AccountGetResponse)

AccountUpdateRequest = _reflection.GeneratedProtocolMessageType('AccountUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTUPDATEREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountUpdateRequest)
  })
_sym_db.RegisterMessage(AccountUpdateRequest)

AccountUpdateResponse = _reflection.GeneratedProtocolMessageType('AccountUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTUPDATERESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountUpdateResponse)
  })
_sym_db.RegisterMessage(AccountUpdateResponse)

AccountDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTDELETEREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountDeleteRequest)
  })
_sym_db.RegisterMessage(AccountDeleteRequest)

AccountDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTDELETERESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountDeleteResponse)
  })
_sym_db.RegisterMessage(AccountDeleteResponse)

AccountListRequest = _reflection.GeneratedProtocolMessageType('AccountListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountListRequest)
  })
_sym_db.RegisterMessage(AccountListRequest)

AccountListResponse = _reflection.GeneratedProtocolMessageType('AccountListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountListResponse)
  })
_sym_db.RegisterMessage(AccountListResponse)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.Account)
  })
_sym_db.RegisterMessage(Account)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.User)
  })
_sym_db.RegisterMessage(User)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:v1.Service)
  })
_sym_db.RegisterMessage(Service)


DESCRIPTOR._options = None
_ACCOUNTCREATEREQUEST.fields_by_name['account']._options = None
_ACCOUNTCREATERESPONSE.fields_by_name['meta']._options = None
_ACCOUNTCREATERESPONSE.fields_by_name['account']._options = None
_ACCOUNTCREATERESPONSE.fields_by_name['token']._options = None
_ACCOUNTCREATERESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTCREATERESPONSE._options = None
_ACCOUNTGETREQUEST.fields_by_name['id']._options = None
_ACCOUNTGETRESPONSE.fields_by_name['meta']._options = None
_ACCOUNTGETRESPONSE.fields_by_name['account']._options = None
_ACCOUNTGETRESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTGETRESPONSE._options = None
_ACCOUNTUPDATEREQUEST.fields_by_name['account']._options = None
_ACCOUNTUPDATERESPONSE.fields_by_name['meta']._options = None
_ACCOUNTUPDATERESPONSE.fields_by_name['account']._options = None
_ACCOUNTUPDATERESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTUPDATERESPONSE._options = None
_ACCOUNTDELETEREQUEST.fields_by_name['id']._options = None
_ACCOUNTDELETERESPONSE.fields_by_name['meta']._options = None
_ACCOUNTDELETERESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTDELETERESPONSE._options = None
_ACCOUNTLISTREQUEST.fields_by_name['filter']._options = None
_ACCOUNTLISTRESPONSE.fields_by_name['accounts']._options = None
_ACCOUNTLISTRESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNT.oneofs_by_name['account']._options = None
_ACCOUNT._options = None
_USER.fields_by_name['id']._options = None
_USER.fields_by_name['email']._options = None
_USER.fields_by_name['first_name']._options = None
_USER.fields_by_name['last_name']._options = None
_USER.fields_by_name['suspended']._options = None
_USER._options = None
_SERVICE.fields_by_name['id']._options = None
_SERVICE.fields_by_name['name']._options = None
_SERVICE.fields_by_name['suspended']._options = None
_SERVICE._options = None

_ACCOUNTS = _descriptor.ServiceDescriptor(
  name='Accounts',
  full_name='v1.Accounts',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312\371\263\007\014\302\371\263\007\007Account'),
  serialized_start=2126,
  serialized_end=2681,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='v1.Accounts.Create',
    index=0,
    containing_service=None,
    input_type=_ACCOUNTCREATEREQUEST,
    output_type=_ACCOUNTCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\021\"\014/v1/accounts:\001*\222A[\"Y\n\033Learn how to make a Account\022:https://www.strongdm.com/docs/api/services/Accounts#Create'),
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='v1.Accounts.Get',
    index=1,
    containing_service=None,
    input_type=_ACCOUNTGETREQUEST,
    output_type=_ACCOUNTGETRESPONSE,
    serialized_options=_b('\202\323\344\223\002\023\022\021/v1/accounts/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='v1.Accounts.Update',
    index=2,
    containing_service=None,
    input_type=_ACCOUNTUPDATEREQUEST,
    output_type=_ACCOUNTUPDATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\026\032\021/v1/accounts/{id}:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='v1.Accounts.Delete',
    index=3,
    containing_service=None,
    input_type=_ACCOUNTDELETEREQUEST,
    output_type=_ACCOUNTDELETERESPONSE,
    serialized_options=_b('\202\323\344\223\002\023*\021/v1/accounts/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='v1.Accounts.List',
    index=4,
    containing_service=None,
    input_type=_ACCOUNTLISTREQUEST,
    output_type=_ACCOUNTLISTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\016\022\014/v1/accounts'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTS)

DESCRIPTOR.services_by_name['Accounts'] = _ACCOUNTS

# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account_grants.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='account_grants.proto',
  package='v1',
  syntax='proto3',
  serialized_options=_b('\n\034com.strongdm.api.v1.plumbingB\025AccountGrantsPlumbing'),
  serialized_pb=_b('\n\x14\x61\x63\x63ount_grants.proto\x12\x02v1\x1a\x1cgoogle/api/annotations.proto\x1a,protoc-gen-swagger/options/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"y\n\x19\x41\x63\x63ountGrantCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xca\x01\n\x1a\x41\x63\x63ountGrantCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16\x41\x63\x63ountGrantGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xc4\x01\n\x17\x41\x63\x63ountGrantGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_grant\x18\x02 \x01(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x19\x41\x63\x63ountGrantDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x95\x01\n\x1a\x41\x63\x63ountGrantDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x17\x41\x63\x63ountGrantListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xaf\x01\n\x18\x41\x63\x63ountGrantListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0e\x61\x63\x63ount_grants\x18\x02 \x03(\x0b\x32\x10.v1.AccountGrantB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x92\x04\n\x0c\x41\x63\x63ountGrant\x12,\n\x02id\x18\x01 \x01(\tB \xf2\xf8\xb3\x07\x1b\xa2\xf3\xb3\x07\x02ID\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\nPermission\x12\x44\n\x0bresource_id\x18\x02 \x01(\tB/\xf2\xf8\xb3\x07*\xa2\xf3\xb3\x07\x0c\x44\x61tasourceID\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\nDatasource\x12\x37\n\naccount_id\x18\x03 \x01(\tB#\xf2\xf8\xb3\x07\x1e\xa2\xf3\xb3\x07\x06UserID\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x04User\x12H\n\nstart_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x18\xf2\xf8\xb3\x07\x13\xa2\xf3\xb3\x07\tStartFrom\xb0\xf3\xb3\x07\x01\x12J\n\x0bvalid_until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x19\xf2\xf8\xb3\x07\x14\xa2\xf3\xb3\x07\nValidUntil\xb0\xf3\xb3\x07\x01:\xbe\x01\xfa\xf8\xb3\x07r\xa2\xf3\xb3\x07\nPermission\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07Y\xa2\xf3\xb3\x07&tf_examples/account_grant_resource.txt\xaa\xf3\xb3\x07)tf_examples/account_grant_data_source.txt\x92\x41\x44\x32\x42\x12@{ \"id\": \"ag-244\", \"resource_id\": \"rs-111\", \"account_id\":\"a-444\"}2\xa3\x04\n\rAccountGrants\x12\xcf\x01\n\x06\x43reate\x12\x1d.v1.AccountGrantCreateRequest\x1a\x1e.v1.AccountGrantCreateResponse\"\x85\x01\x82\xd3\xe4\x93\x02\x17\"\x12/v1/account_grants:\x01*\x92\x41\x65\"c\n Learn how to make a AccountGrant\x12?https://www.strongdm.com/docs/api/services/AccountGrants#Create\x12_\n\x03Get\x12\x1a.v1.AccountGrantGetRequest\x1a\x1b.v1.AccountGrantGetResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/account_grants/{id}\x12h\n\x06\x44\x65lete\x12\x1d.v1.AccountGrantDeleteRequest\x1a\x1e.v1.AccountGrantDeleteResponse\"\x1f\x82\xd3\xe4\x93\x02\x19*\x17/v1/account_grants/{id}\x12]\n\x04List\x12\x1b.v1.AccountGrantListRequest\x1a\x1c.v1.AccountGrantListResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/account_grants\x1a\x16\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0c\x41\x63\x63ountGrantB5\n\x1c\x63om.strongdm.api.v1.plumbingB\x15\x41\x63\x63ountGrantsPlumbingb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,options__pb2.DESCRIPTOR,spec__pb2.DESCRIPTOR,])




_ACCOUNTGRANTCREATEREQUEST = _descriptor.Descriptor(
  name='AccountGrantCreateRequest',
  full_name='v1.AccountGrantCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantCreateRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_grant', full_name='v1.AccountGrantCreateRequest.account_grant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=285,
)


_ACCOUNTGRANTCREATERESPONSE = _descriptor.Descriptor(
  name='AccountGrantCreateResponse',
  full_name='v1.AccountGrantCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantCreateResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_grant', full_name='v1.AccountGrantCreateResponse.account_grant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountGrantCreateResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=490,
)


_ACCOUNTGRANTGETREQUEST = _descriptor.Descriptor(
  name='AccountGrantGetRequest',
  full_name='v1.AccountGrantGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantGetRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountGrantGetRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=578,
)


_ACCOUNTGRANTGETRESPONSE = _descriptor.Descriptor(
  name='AccountGrantGetResponse',
  full_name='v1.AccountGrantGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantGetResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_grant', full_name='v1.AccountGrantGetResponse.account_grant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountGrantGetResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=777,
)


_ACCOUNTGRANTDELETEREQUEST = _descriptor.Descriptor(
  name='AccountGrantDeleteRequest',
  full_name='v1.AccountGrantDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantDeleteRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountGrantDeleteRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=871,
)


_ACCOUNTGRANTDELETERESPONSE = _descriptor.Descriptor(
  name='AccountGrantDeleteResponse',
  full_name='v1.AccountGrantDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantDeleteResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountGrantDeleteResponse.rate_limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007\005\250\363\263\007\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=1023,
)


_ACCOUNTGRANTLISTREQUEST = _descriptor.Descriptor(
  name='AccountGrantListRequest',
  full_name='v1.AccountGrantListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantListRequest.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='v1.AccountGrantListRequest.filter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1117,
)


_ACCOUNTGRANTLISTRESPONSE = _descriptor.Descriptor(
  name='AccountGrantListResponse',
  full_name='v1.AccountGrantListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='v1.AccountGrantListResponse.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_grants', full_name='v1.AccountGrantListResponse.account_grants', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\270\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rate_limit', full_name='v1.AccountGrantListResponse.rate_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\005\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1295,
)


_ACCOUNTGRANT = _descriptor.Descriptor(
  name='AccountGrant',
  full_name='v1.AccountGrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.AccountGrant.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\033\242\363\263\007\002ID\260\363\263\007\001\312\363\263\007\nPermission'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='v1.AccountGrant.resource_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007*\242\363\263\007\014DatasourceID\260\363\263\007\001\300\363\263\007\001\312\363\263\007\nDatasource'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='v1.AccountGrant.account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\036\242\363\263\007\006UserID\260\363\263\007\001\300\363\263\007\001\312\363\263\007\004User'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_from', full_name='v1.AccountGrant.start_from', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\023\242\363\263\007\tStartFrom\260\363\263\007\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valid_until', full_name='v1.AccountGrant.valid_until', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\362\370\263\007\024\242\363\263\007\nValidUntil\260\363\263\007\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\372\370\263\007r\242\363\263\007\nPermission\250\363\263\007\001\302\363\263\007Y\242\363\263\007&tf_examples/account_grant_resource.txt\252\363\263\007)tf_examples/account_grant_data_source.txt\222AD2B\022@{ \"id\": \"ag-244\", \"resource_id\": \"rs-111\", \"account_id\":\"a-444\"}'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1298,
  serialized_end=1828,
)

_ACCOUNTGRANTCREATEREQUEST.fields_by_name['meta'].message_type = spec__pb2._CREATEREQUESTMETADATA
_ACCOUNTGRANTCREATEREQUEST.fields_by_name['account_grant'].message_type = _ACCOUNTGRANT
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['meta'].message_type = spec__pb2._CREATERESPONSEMETADATA
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['account_grant'].message_type = _ACCOUNTGRANT
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTGRANTGETREQUEST.fields_by_name['meta'].message_type = spec__pb2._GETREQUESTMETADATA
_ACCOUNTGRANTGETRESPONSE.fields_by_name['meta'].message_type = spec__pb2._GETRESPONSEMETADATA
_ACCOUNTGRANTGETRESPONSE.fields_by_name['account_grant'].message_type = _ACCOUNTGRANT
_ACCOUNTGRANTGETRESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTGRANTDELETEREQUEST.fields_by_name['meta'].message_type = spec__pb2._DELETEREQUESTMETADATA
_ACCOUNTGRANTDELETERESPONSE.fields_by_name['meta'].message_type = spec__pb2._DELETERESPONSEMETADATA
_ACCOUNTGRANTDELETERESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTGRANTLISTREQUEST.fields_by_name['meta'].message_type = spec__pb2._LISTREQUESTMETADATA
_ACCOUNTGRANTLISTRESPONSE.fields_by_name['meta'].message_type = spec__pb2._LISTRESPONSEMETADATA
_ACCOUNTGRANTLISTRESPONSE.fields_by_name['account_grants'].message_type = _ACCOUNTGRANT
_ACCOUNTGRANTLISTRESPONSE.fields_by_name['rate_limit'].message_type = spec__pb2._RATELIMITMETADATA
_ACCOUNTGRANT.fields_by_name['start_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCOUNTGRANT.fields_by_name['valid_until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['AccountGrantCreateRequest'] = _ACCOUNTGRANTCREATEREQUEST
DESCRIPTOR.message_types_by_name['AccountGrantCreateResponse'] = _ACCOUNTGRANTCREATERESPONSE
DESCRIPTOR.message_types_by_name['AccountGrantGetRequest'] = _ACCOUNTGRANTGETREQUEST
DESCRIPTOR.message_types_by_name['AccountGrantGetResponse'] = _ACCOUNTGRANTGETRESPONSE
DESCRIPTOR.message_types_by_name['AccountGrantDeleteRequest'] = _ACCOUNTGRANTDELETEREQUEST
DESCRIPTOR.message_types_by_name['AccountGrantDeleteResponse'] = _ACCOUNTGRANTDELETERESPONSE
DESCRIPTOR.message_types_by_name['AccountGrantListRequest'] = _ACCOUNTGRANTLISTREQUEST
DESCRIPTOR.message_types_by_name['AccountGrantListResponse'] = _ACCOUNTGRANTLISTRESPONSE
DESCRIPTOR.message_types_by_name['AccountGrant'] = _ACCOUNTGRANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountGrantCreateRequest = _reflection.GeneratedProtocolMessageType('AccountGrantCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTCREATEREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantCreateRequest)
  })
_sym_db.RegisterMessage(AccountGrantCreateRequest)

AccountGrantCreateResponse = _reflection.GeneratedProtocolMessageType('AccountGrantCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTCREATERESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantCreateResponse)
  })
_sym_db.RegisterMessage(AccountGrantCreateResponse)

AccountGrantGetRequest = _reflection.GeneratedProtocolMessageType('AccountGrantGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTGETREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantGetRequest)
  })
_sym_db.RegisterMessage(AccountGrantGetRequest)

AccountGrantGetResponse = _reflection.GeneratedProtocolMessageType('AccountGrantGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTGETRESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantGetResponse)
  })
_sym_db.RegisterMessage(AccountGrantGetResponse)

AccountGrantDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountGrantDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTDELETEREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantDeleteRequest)
  })
_sym_db.RegisterMessage(AccountGrantDeleteRequest)

AccountGrantDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountGrantDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTDELETERESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantDeleteResponse)
  })
_sym_db.RegisterMessage(AccountGrantDeleteResponse)

AccountGrantListRequest = _reflection.GeneratedProtocolMessageType('AccountGrantListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTLISTREQUEST,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantListRequest)
  })
_sym_db.RegisterMessage(AccountGrantListRequest)

AccountGrantListResponse = _reflection.GeneratedProtocolMessageType('AccountGrantListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANTLISTRESPONSE,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrantListResponse)
  })
_sym_db.RegisterMessage(AccountGrantListResponse)

AccountGrant = _reflection.GeneratedProtocolMessageType('AccountGrant', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGRANT,
  '__module__' : 'account_grants_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGrant)
  })
_sym_db.RegisterMessage(AccountGrant)


DESCRIPTOR._options = None
_ACCOUNTGRANTCREATEREQUEST.fields_by_name['account_grant']._options = None
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['meta']._options = None
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['account_grant']._options = None
_ACCOUNTGRANTCREATERESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTGRANTCREATERESPONSE._options = None
_ACCOUNTGRANTGETREQUEST.fields_by_name['id']._options = None
_ACCOUNTGRANTGETRESPONSE.fields_by_name['meta']._options = None
_ACCOUNTGRANTGETRESPONSE.fields_by_name['account_grant']._options = None
_ACCOUNTGRANTGETRESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTGRANTGETRESPONSE._options = None
_ACCOUNTGRANTDELETEREQUEST.fields_by_name['id']._options = None
_ACCOUNTGRANTDELETERESPONSE.fields_by_name['meta']._options = None
_ACCOUNTGRANTDELETERESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTGRANTDELETERESPONSE._options = None
_ACCOUNTGRANTLISTREQUEST.fields_by_name['filter']._options = None
_ACCOUNTGRANTLISTRESPONSE.fields_by_name['account_grants']._options = None
_ACCOUNTGRANTLISTRESPONSE.fields_by_name['rate_limit']._options = None
_ACCOUNTGRANT.fields_by_name['id']._options = None
_ACCOUNTGRANT.fields_by_name['resource_id']._options = None
_ACCOUNTGRANT.fields_by_name['account_id']._options = None
_ACCOUNTGRANT.fields_by_name['start_from']._options = None
_ACCOUNTGRANT.fields_by_name['valid_until']._options = None
_ACCOUNTGRANT._options = None

_ACCOUNTGRANTS = _descriptor.ServiceDescriptor(
  name='AccountGrants',
  full_name='v1.AccountGrants',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312\371\263\007\021\302\371\263\007\014AccountGrant'),
  serialized_start=1831,
  serialized_end=2378,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='v1.AccountGrants.Create',
    index=0,
    containing_service=None,
    input_type=_ACCOUNTGRANTCREATEREQUEST,
    output_type=_ACCOUNTGRANTCREATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/account_grants:\001*\222Ae\"c\n Learn how to make a AccountGrant\022?https://www.strongdm.com/docs/api/services/AccountGrants#Create'),
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='v1.AccountGrants.Get',
    index=1,
    containing_service=None,
    input_type=_ACCOUNTGRANTGETREQUEST,
    output_type=_ACCOUNTGRANTGETRESPONSE,
    serialized_options=_b('\202\323\344\223\002\031\022\027/v1/account_grants/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='v1.AccountGrants.Delete',
    index=2,
    containing_service=None,
    input_type=_ACCOUNTGRANTDELETEREQUEST,
    output_type=_ACCOUNTGRANTDELETERESPONSE,
    serialized_options=_b('\202\323\344\223\002\031*\027/v1/account_grants/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='v1.AccountGrants.List',
    index=3,
    containing_service=None,
    input_type=_ACCOUNTGRANTLISTREQUEST,
    output_type=_ACCOUNTGRANTLISTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\022\022/v1/account_grants'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTGRANTS)

DESCRIPTOR.services_by_name['AccountGrants'] = _ACCOUNTGRANTS

# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 

# This file was generated by protogen. DO NOT EDIT.

import grpc
import hmac
import random
import hashlib
import base64
import datetime
import time
from . import svc
from . import plumbing

# These defaults are taken from AWS. Customization of these values
# is a future step in the API.
DEFAULT_MAX_RETRIES = 3
DEFAULT_BASE_RETRY_DELAY = 0.0030 # 30 ms
DEFAULT_MAX_RETRY_DELAY = 300 # 300 seconds


class Client:
    """Client interacts with the strongDM API.

    :param api_access_key: the access key to authenticate with strongDM
    :param api_secret: the secret key to authenticate with strongDM
    """

    def __init__(self, api_access_key, api_secret, host = 'api.strongdm.com:443', insecure = False):
        self.api_access_key = api_access_key
        self.api_secret = base64.b64decode(api_secret)
        self.max_retries = DEFAULT_MAX_RETRIES
        self.base_retry_delay = DEFAULT_BASE_RETRY_DELAY
        self.max_retry_delay = DEFAULT_MAX_RETRY_DELAY

        try:
            if insecure:
                channel = grpc.insecure_channel(host)
            else:
                creds = grpc.ssl_channel_credentials()
                channel = grpc.secure_channel(host, creds)
            self.account_attachments = svc.AccountAttachments(channel, self)
            self.account_grants = svc.AccountGrants(channel, self)
            self.accounts = svc.Accounts(channel, self)
            self.nodes = svc.Nodes(channel, self)
            self.resources = svc.Resources(channel, self)
            self.role_attachments = svc.RoleAttachments(channel, self)
            self.role_grants = svc.RoleGrants(channel, self)
            self.roles = svc.Roles(channel, self)
        except Exception as e:
            raise plumbing.error_to_porcelain(e) from e
        self._test_options = {}

    def get_metadata(self, method_name, req):
        return [('x-sdm-authentication', self.api_access_key), ('x-sdm-signature',self.sign(method_name, req.SerializeToString()))]

    def sign(self, method_name, request_bytes):
        def hmac_digest(key, msg_byte_string):
            return hmac.new(key, msg=msg_byte_string, digestmod=hashlib.sha256).digest()

        current_utc_date = datetime.datetime.utcnow().strftime('%Y-%m-%d')
        signing_key = hmac_digest(self.api_secret, current_utc_date.encode())
        signing_key = hmac_digest(signing_key, b'sdm_api_v1')

        hash = hashlib.sha256()

        hash.update(method_name.encode())
        hash.update(b'\n')
        hash.update(request_bytes)

        return base64.b64encode(hmac_digest(signing_key,hash.digest()))

    def jitterSleep(self, iter):
        dur_max = self.base_retry_delay * 2**iter
        if (dur_max > self.max_retry_delay):
            dur_max = self.max_retry_delay
        # get a value between 0 and max
        dur = random.random() * dur_max
        time.sleep(dur)

    def shouldRetry(self, iter, err):
        if (iter >= self.max_retries-1):
            return False
        if not isinstance(err, grpc.RpcError):
            return True
        return err.code() == grpc.StatusCode.INTERNAL



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import role_grants_pb2 as role__grants__pb2


class RoleGrantsStub(object):
  """RoleGrants represent relationships between composite roles and the roles
  that make up those composite roles. When a composite role is attached to another
  role, the permissions granted to members of the composite role are augmented to
  include the permissions granted to members of the attached role.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/v1.RoleGrants/Create',
        request_serializer=role__grants__pb2.RoleGrantCreateRequest.SerializeToString,
        response_deserializer=role__grants__pb2.RoleGrantCreateResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/v1.RoleGrants/Get',
        request_serializer=role__grants__pb2.RoleGrantGetRequest.SerializeToString,
        response_deserializer=role__grants__pb2.RoleGrantGetResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/v1.RoleGrants/Delete',
        request_serializer=role__grants__pb2.RoleGrantDeleteRequest.SerializeToString,
        response_deserializer=role__grants__pb2.RoleGrantDeleteResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/v1.RoleGrants/List',
        request_serializer=role__grants__pb2.RoleGrantListRequest.SerializeToString,
        response_deserializer=role__grants__pb2.RoleGrantListResponse.FromString,
        )


class RoleGrantsServicer(object):
  """RoleGrants represent relationships between composite roles and the roles
  that make up those composite roles. When a composite role is attached to another
  role, the permissions granted to members of the composite role are augmented to
  include the permissions granted to members of the attached role.
  """

  def Create(self, request, context):
    """Create registers a new RoleGrant.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    """Get reads one RoleGrant by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """Delete removes a RoleGrant by ID.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """List gets a list of RoleGrants matching a given set of criteria.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RoleGrantsServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=role__grants__pb2.RoleGrantCreateRequest.FromString,
          response_serializer=role__grants__pb2.RoleGrantCreateResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=role__grants__pb2.RoleGrantGetRequest.FromString,
          response_serializer=role__grants__pb2.RoleGrantGetResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=role__grants__pb2.RoleGrantDeleteRequest.FromString,
          response_serializer=role__grants__pb2.RoleGrantDeleteResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=role__grants__pb2.RoleGrantListRequest.FromString,
          response_serializer=role__grants__pb2.RoleGrantListResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'v1.RoleGrants', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
